Type: Package
Package: SingleCellMultiModal
Title: Integrating Multi-modal Single Cell Experiment datasets
Version: 1.25.3
Date: 2025-06-12
Authors@R: c(
    person("Marcel", "Ramos", , "marcel.ramos@sph.cuny.edu", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-3242-0582")),
    person("Ricard", "Argelaguet", , "ricard@ebi.ac.uk", role = "aut"),
    person("Al", "Abadi", role = "ctb"),
    person("Dario", "Righelli", , "dario.righelli@gmail.com", role = "aut"),
    person("Christophe", "Vanderaa", , "christophe.vanderaa@uclouvain.be", role = "ctb"),
    person("Kelly", "Eckenrode", , "kelly.eckenrode@sph.cuny.edu", role = "aut"),
    person("Ludwig", "Geistlinger", , "ludwig_geistlinger@hms.harvard.edu", role = "aut"),
    person("Levi", "Waldron", , "lwaldron.research@gmail.com", role = "aut"),
    person("NCI", role = "fnd",
           comment = c(GrantNo. = "U24CA289073"))
  )
Description: SingleCellMultiModal is an ExperimentHub package
    that serves multiple datasets obtained from GEO and other sources and
    represents them as MultiAssayExperiment objects. We provide several
    multi-modal datasets including scNMT, 10X Multiome, seqFISH, CITEseq,
    SCoPE2, and others. The scope of the package is is to provide data for
    benchmarking and analysis. To cite, use the 'citation' function and see 
    <https://doi.org/10.1371/journal.pcbi.1011324>.
License: Artistic-2.0
BugReports: https://github.com/waldronlab/SingleCellMultiModal/issues
Depends: R (>= 4.2.0), MultiAssayExperiment
Imports: AnnotationHub, BiocBaseUtils, BiocFileCache, ExperimentHub,
        graphics, HDF5Array, S4Vectors, SingleCellExperiment,
        SpatialExperiment, SummarizedExperiment, Matrix, methods, utils
Suggests: BiocStyle, ggplot2, knitr, RaggedExperiment, rmarkdown,
        scater, scran, UpSetR, uwot
VignetteBuilder: knitr
biocViews: ExperimentData, SingleCellData, ReproducibleResearch,
        ExperimentHub, GEO
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
Config/roxygen2/version: 8.0.0
git_url: https://git.bioconductor.org/packages/SingleCellMultiModal
git_branch: devel
git_last_commit: cdbd97d
git_last_commit_date: 2026-05-20
Repository: Bioconductor 3.24
Date/Publication: 2026-05-21
NeedsCompilation: no
Packaged: 2026-05-21 15:49:07 UTC; biocbuild
Author: Marcel Ramos [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-3242-0582>),
  Ricard Argelaguet [aut],
  Al Abadi [ctb],
  Dario Righelli [aut],
  Christophe Vanderaa [ctb],
  Kelly Eckenrode [aut],
  Ludwig Geistlinger [aut],
  Levi Waldron [aut],
  NCI [fnd] (GrantNo.: U24CA289073)
Maintainer: Marcel Ramos <marcel.ramos@sph.cuny.edu>
