# Generated by roxygen2: do not edit by hand

export(CITEseq)
export(GTseq)
export(SCoPE2)
export(SingleCellMultiModal)
export(addCTLabels)
export(getCellGroups)
export(ontomap)
export(removeCache)
export(scMultiome)
export(scNMT)
export(scmmCache)
export(seqFISH)
export(setCache)
import(MultiAssayExperiment)
importFrom(AnnotationHub,query)
importFrom(ExperimentHub,ExperimentHub)
importFrom(ExperimentHub,loadResources)
importFrom(Matrix,Matrix)
importFrom(MultiAssayExperiment,experiments)
importFrom(S4Vectors,DataFrame)
importFrom(S4Vectors,SimpleList)
importFrom(SingleCellExperiment,"altExp<-")
importFrom(SingleCellExperiment,"altExps<-")
importFrom(SingleCellExperiment,SingleCellExperiment)
importFrom(SingleCellExperiment,altExp)
importFrom(SingleCellExperiment,altExps)
importFrom(SingleCellExperiment,colData)
importFrom(SingleCellExperiment,counts)
importFrom(SpatialExperiment,SpatialExperiment)
importFrom(SummarizedExperiment,"assays<-")
importFrom(SummarizedExperiment,SummarizedExperiment)
importFrom(graphics,abline)
importFrom(graphics,smoothScatter)
importFrom(graphics,text)
importFrom(methods,is)
importFrom(utils,glob2rx)
importFrom(utils,read.csv)
