---
output: github_document
knit: (function(inputFile, encoding) {
  rmarkdown::render(inputFile, encoding = encoding, output_dir = "../../") })
bibliography: ../REFERENCES.bib
---

```{r, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  cache = TRUE,
  out.width = "100%"
)
```

```{r,echo=FALSE,eval=FALSE}
## Generate the ./README.md (relative to base folder)
rmarkdown::render(input = "inst/scripts/README.Rmd", output_dir = ".")
```

# <a href='https://waldronlab.github.io/SingleCellMultiModal'><img src='https://raw.githubusercontent.com/Bioconductor/BiocStickers/devel/SingleCellMultiModal/SingleCellMultiModal.png' align="right" height="139" /></a>

```{r, child="../../vignettes/SingleCellMultiModal.Rmd"}

```
