##
## PLACEHOLDER for make-data/
##
## see the respective R script for each technology
##
## for example, make-data/scNMT.R for an example on how
## we took a MultiAssayExperiment object and created
## Rda files for upload to ExperimentHub
##
## see make-data/scMultiome.R for converting a MultiAssayExperiment
## into sparceMatrix representations using HDF5 and MTX formats
##
## see make-data/make-macrophage.R for taking raw data and
## creating SingleCellExperiment data products
##
