#' @importFrom ExperimentHub loadResources ExperimentHub
#' @importFrom AnnotationHub query
#' @importFrom utils glob2rx read.csv
#' @import MultiAssayExperiment
NULL

#' SingleCellMultiModal-package
#'
#' @aliases NULL SingleCellMultiModal-package
#'
#' @description
#' The SingleCellMultiModal package provides a convenient and user-friendly
#' representation of multi-modal data from project such as `scNMT` for mouse
#' gastrulation.
#'
#' @examples
#' help(package = "SingleCellMultiModal")
#'
"_PACKAGE"
