---
title: "SingleCellMultiModal Introduction"
date: "`r BiocStyle::doc_date()`"
vignette: |
  %\VignetteIndexEntry{SingleCellMultiModal Introduction}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
output:
    BiocStyle::html_document:
      toc_float: true
package: SingleCellMultiModal
bibliography: ../inst/REFERENCES.bib
---

# SingleCellMultiModal

## Overview 

`SingleCellMultiModal` is an R package that provides a convenient and
user-friendly representation of multi-modal data using `MultiAssayExperiment`.
This package introduces a suite of single-cell multimodal landmark datasets for
benchmarking and testing multimodal analysis methods via the `ExperimentHub`
Bioconductor package. The scope of this package is to provide efficient access
to a selection of curated, pre-integrated, publicly available landmark datasets
for methods development and benchmarking.

## Installation

```{r,eval=FALSE}
if (!requireNamespace("BiocManager", quietly = TRUE))
    install.packages("BiocManager")

BiocManager::install("SingleCellMultiModal")
```

## Loading packages

```{r,include=TRUE,results="hide",message=FALSE,warning=FALSE}
library(SingleCellMultiModal)
library(MultiAssayExperiment)
```

# Citing SingleCellMultiModal

Your citations are crucial in keeping our software free and open source. To
cite our package see the citation (@Eckenrode2023-yq) in the Reference
section. You may also browse to the publication at
[PLoS Computational Biology][1].

[1]: https://doi.org/10.1371/journal.pcbi.1011324

## Representation

Users can obtain integrative representations of multiple modalities as a
`MultiAssayExperiment`, a common core Bioconductor data structure relied on by
dozens of multimodal data analysis packages. `MultiAssayExperiment` harmonizes
data management of multiple experimental assays performed on an overlapping set
of specimens. Although originally developed for patient data from multi-omics
cancer studies, the `MultiAssayExperiment` framework naturally applies also to
single cells. A schematic of the data structure can be seen below. In this
context, "patients" are replaced by "cells". We use `MultiAssayExperiment`
because it provides a familiar user experience by extending
`SummarizedExperiment` concepts and providing open ended compatibility with
standard data classes present in Bioconductor such as the
`SingleCellExperiment`.

```{r,echo=FALSE}
imgurl <- paste0(
    "https://github.com/waldronlab/MultiAssayExperiment/blob/",
    "c3c59a094e5a08111ee98b9f69579db5634d9fd4/vignettes/",
    "MultiAssayExperiment.png?raw=true"
)
knitr::include_graphics(
    path = imgurl
)
```

# Contributions

Want to contribute to the `SingleCellMultiModal` package? We welcome
contributions from the community. Please refer to our
[Contributing Guidelines][2] for more details.

[2]: https://github.com/waldronlab/SingleCellMultiModal/wiki/Contributing-Guidelines


## Further resources

For more information on the `MultiAssayExperiment` data structure, please refer
to @Ramos2017-tk as well as the [MultiAssayExperiment vignette][3].

[3]: https://bioconductor.org/packages/release/bioc/vignettes/MultiAssayExperiment/inst/doc/MultiAssayExperiment.html

# References
