% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/CITEseq.R
\name{.CITEseqMaeToSce}
\alias{.CITEseqMaeToSce}
\title{CITEseqMaeToSce}
\usage{
.CITEseqMaeToSce(mae)
}
\arguments{
\item{mae}{a MultiAssayExperiment object with scRNA and/or scADT and/or
scHTO named experiments.}
}
\value{
a SingleCellExperiment object as widely with scRNA data as counts
and scADT, scHTO data as altExps.
If only one modality is present, it has returned as main assay of the SCE.
}
\description{
converts a \code{MultiAssayExperiment} object with CITEseq data into
a \code{SingleCellExperiment} object to be used with already known methods and
packages in literature.

Note that for creating a \code{SingleCellExperiment} object the following function
subsets all the assays present in the \code{MultiAssayExperiment} with only the
common cells across all the modalities.
This could result in a not complete object.
}
\keyword{internal}
